elephant.asset.asset.synchronous\_events\_contains\_all
=======================================================

.. currentmodule:: elephant.asset.asset

.. autofunction:: synchronous_events_contains_all